@@ -5,8 +5,7 @@ from audig import TocarAudios
 
 class Run:
     def __init__(self):
-        pass
-        # self.run()
+        self.run()
 
     def run(self) -> None:
         # Diretório raiz do curso.
